@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from django.conf import settings
 from django.http import HttpResponseBadRequest
+from .utils import add_default_headers
 
 def events(request, **kwargs):
 	from .eventrequest import EventRequest
@@ -35,13 +35,6 @@ def events(request, **kwargs):
 			str(e),
 			{'channels': e.channels})
 
-	response['Cache-Control'] = 'no-cache'
-
-	cors_origin = ''
-	if hasattr(settings, 'EVENTSTREAM_ALLOW_ORIGIN'):
-		cors_origin = settings.EVENTSTREAM_ALLOW_ORIGIN
-
-	if cors_origin:
-		response['Access-Control-Allow-Origin'] = cors_origin
+	add_default_headers(response)
 
 	return response
